      subroutine potini 
c
      implicit none
c
      include "bounds.p"
      include "Constants.p"
      include "System.h"
      include "Lennard_Jones.p"
      include "Lennard_Jones.h"
      include "Phantom.h"
      include "Increm.h"
c
      integer      i, k, nintr, nends
c
      real*8       U1, U1p, U1pp, Rtruncsq(3)
      real*8       psin, del
      real*8       sig6, sig12
      real*8       r2(3), r(3)
      real*8       coeff(0:5), c1, c2, c3
      real*8       Ispl, ILJ, truncsc(3)
      real*8       sigsq(3), ratio, ratio6, ratio3, small(3)
c
c     _______________________________________________________________
c
c     Do loop over different epsilon parameters

      do i=1,3

      anb(i)      = 4.d0 * eps(i) * sigreal(i)**12
      cnb(i)      = 4.d0 * eps(i) * sigreal(i)**6
      Rtrunc(i)    = 1.45d0 * sigreal(i)
      rmaxnb(i)    = (1.45d0 + 0.85d0) * sigreal(i)
      r2nb(i)      = rmaxnb(i) * rmaxnb(i)
      r2nbp(i)     = (rmaxnb(i) + shell)**2
      Rtruncsq(i)  = Rtrunc(i) * Rtrunc(i)
      del       = (rmaxnb(i) - Rtrunc(i)) / sigreal(i)
      U1        = (anb(i)/Rtrunc(i)**12)-(cnb(i)/Rtrunc(i)**6)
      U1p       = -12.d0 * (anb(i)/Rtrunc(i)**13)+ 6.d0*
     :            (cnb(i)/Rtrunc(i)**7)
      U1pp      = 156.d0 * (anb(i)/Rtrunc(i)**14) - 42.d0*
     :            (cnb(i)/Rtrunc(i)**8)
c
c     coefficients for the quintic spline approximation to the 
c     Lennard-Jones potential:
c
      c1 = U1
      c2 = del * U1p * sigreal(i)
      c3 = 0.5d0 * (del*del) * U1pp * (sigreal(i)*sigreal(i))
c
      coeff(0) = c1
      coeff(1) = c2
      coeff(2) = c3
      coeff(3) = -(10.d0 * c1) - (6.d0 * c2) - (3.d0 * c3)
      coeff(4) =  (15.d0 * c1) + (8.d0 * c2) + (3.d0 * c3)
      coeff(5) = -(6.d0  * c1) - (3.d0 * c2) -         c3
c
c     Integral of the Lennard-Jones from Rtrunc to rmaxnb:
c
      sig6  = sigreal(i) ** 6
      sig12 = sigreal(i) ** 12
c
      ILJ = (- (sig12/9.d0) * (1.d0/rmaxnb(i)**9 - 1.d0/Rtrunc(i)**9)
     :       + (sig6 /3.d0) * (1.d0/rmaxnb(i)**3 - 1.d0/Rtrunc(i)**3)) 
     :       * 4.d0 * eps(i)
c
c     Integral of the quintic spline from Rtrunc to rmaxnb:
c
      Ispl =  ( coeff(0)   + coeff(1)/2 + coeff(2)/3 
     :        + coeff(3)/4 + coeff(4)/5 + coeff(5)/6 ) *
     :            (rmaxnb(i) - Rtrunc(i))     * Rtrunc(i)**2 +
     :        ( coeff(0)/2 + coeff(1)/3 + coeff(2)/4
     :        + coeff(3)/5 + coeff(4)/6 + coeff(5)/7 ) *
     :            (rmaxnb(i) - Rtrunc(i))**2  * Rtrunc(i) * 2.d0 +
     :        ( coeff(0)/3 + coeff(1)/4 + coeff(2)/5
     :        + coeff(3)/6 + coeff(4)/7 + coeff(5)/8 ) *
     :            (rmaxnb(i) - Rtrunc(i))**3
c
c
c     The truncation potential (before multiplication by rho/2)
c     between Rtrunc and rmaxnb; also beyond rmaxnb;
c     compute the potential dividing the region {sigma^2/ 8, rmaxnb*1.2}
c     into ngridnb intervals; piece together the potential in "elj"
c
c
      truncsc(i) = 4.d0 * pi * (ILJ - Ispl)
      truncsc(i) = truncsc(i) - 4.d0 * pi * (cnb(i)/3.d0) 
     :             / (rmaxnb(i)**3) + 4.d0 * pi *(anb(i)/9.d0)
     :             / (rmaxnb(i)**9)
      sigsq(i)     = sigreal(i) * sigreal(i)
      small(i)     = sigsq(i) / 8.d0
      interval(i)  = (r2nb(i) * 1.2d0) / ngridnb
c
c
c
      do k = 1, ngridnb
         r2(i) = (interval(i) * k)
         r(i)  = dsqrt(r2(i))
c
         if      (r2(i).lt.small(i)) then
           elj(k,i) = 1.d5
            flj(k,i) = 1.d5

         else if (r2(i).lt.Rtruncsq(i)) then
c	if (r2(i).le.r2nb(i)) then

          ratio  = sigsq(i) / r2(i)
	    ratio6 = ratio**6
	    ratio3 = ratio**3
          elj(k,i) = 4.d0 * eps(i) * (ratio6 - ratio3)
	    vlj(k,i) = 48.d0 * eps(i)* (ratio6 - 0.5*
     :                 ratio3)
	    flj(k,i) = vlj(k,i)/r(i)
     
c            write(*,*)"elj",k,r2,elj(k,i),"full"
         else if (r2(i).lt.r2nb(i)) then
            psin = (r(i) - Rtrunc(i)) / (rmaxnb(i) - Rtrunc(i))
            elj(k,i) = coeff(0) + psin * (
     :                coeff(1) +  psin * (
     :                coeff(2) +  psin * (
     :                coeff(3) +  psin * (
     :                coeff(4) +  psin * (
     :                coeff(5))))))

	    vlj(k,i) = coeff(1) + psin * (
     :                 2*coeff(2) + psin * (
     :                 3*coeff(3) + psin * (
     :                 4*coeff(4) + psin * (
     :                 5*coeff(5)))))
	    flj(k,i) = -vlj(k,i)/(rmaxnb(i) - Rtrunc(i))
	    vlj(k,i) = flj(k,i)*r(i)
c            write(*,*)"elj",k,r2,elj(k,i),"spline"
         else
          elj(k,i) = 0.d0
	    vlj(k,i) = 0.d0
	    flj(k,i) = 0.d0
c            write(*,*)"elj",k,r2,elj(k,i),"0"
       end if   
      end do

      enddo
c
c    
      return
      end


